ImpaktfullUiNotificationColorTheme class

Constructors

ImpaktfullUiNotificationColorTheme({required Color background, required Color? border, required Color shadow, required Color branded, required Color error, required Color info, bool matchBorderWithType = false, required Color success, required Color warning})
const

Properties

background Color
final
border Color?
final
branded Color
final
error Color
final
hashCode int
The hash code for this object.
no setterinherited
info Color
final
matchBorderWithType bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadow Color
final
success Color
final
warning Color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited